@@ -1,5 +1,5 @@
 ;;; org-node-context.el ---  -*- lexical-binding: t; -*-
-;; Copyright (C) 2025 Martin Edström
+;; Copyright (C) 2025-2026 Martin Edström
 
 ;; This program is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -135,7 +135,8 @@ but when this finds one of them stale, it removes that whole entry."
   "C-m"                     'org-node-context-visit-thing
   "l"                       'org-node-context-history-go-back
   "r"                       'org-node-context-history-go-forward
-  "<remap> <revert-buffer>" 'org-node-context-refresh-this-buffer)
+  "<remap> <revert-buffer-quick>" 'org-node-context-refresh-this-buffer
+  "<remap> <revert-buffer>"       'org-node-context-refresh-this-buffer)
 
 (define-derived-mode org-node-context-mode magit-section-mode "Org-Node-Context"
   "Major mode for the context buffer."
@@ -453,12 +454,14 @@ that buffer."
         (setq header-line-format
               (concat "Context for \"" (org-mem-entry-title node) "\""))
         (magit-insert-section (org-node-context node)
-          (when-let* ((links (org-mem-id-links-to-entry node)))
+          (when-let* ((links (seq-filter #'org-mem-link-nearby-id
+                                         (org-mem-id-links-to-entry node))))
             (magit-insert-section (org-node-context 'id-links)
               (magit-insert-heading "ID backlinks:")
               (org-node-context--insert-backlink-sections links)
               (insert "\n")))
-          (when-let* ((links (org-mem-roam-reflinks-to-entry node)))
+          (when-let* ((links (seq-filter #'org-mem-link-nearby-id
+                                         (org-mem-roam-reflinks-to-entry node))))
             (magit-insert-section (org-node-context 'reflinks)
               (magit-insert-heading "Ref backlinks:")
               (org-node-context--insert-backlink-sections links)
