@@ -1,6 +1,6 @@
 ;;; org-node-seq.el --- Experimental way to define node sequences -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2024-2025 Martin Edström
+;; Copyright (C) 2024-2026 Martin Edström
 ;;
 ;; This program is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -289,7 +289,7 @@ Jump/Next/Previous/Capture actions.
 
 NAME describes the sequence, in one or a few words.
 
-CLASSIFIER is a single-argument function taking an `org-node' object
+CLASSIFIER is a single-argument function taking an `org-mem-entry' object
 and should return a list or cons cell if a sequence-item was found,
 otherwise nil.
 
